# -*- coding: utf-8 -*-

import urllib

import requests
from django.urls import reverse


class RemoteTestMixin:
    # GENERIC TEMPLATE

    def v1_template_generic_template_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-template:generictemplate-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_template_generic_template_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-template:generictemplate-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_template_generic_template_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-template:generictemplate-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_template_generic_template_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-template:generictemplate-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_template_generic_template_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-template:generictemplate-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_template_generic_template_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-template:generictemplate-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_template_generic_template_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-template:generictemplate-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_template_generic_template_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-template:generictemplate-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_template_generic_template_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-template:generictemplate-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # EMAIL TEMPLATE

    def v1_template_email_template_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-template:emailtemplate-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_template_email_template_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-template:emailtemplate-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_template_email_template_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-template:emailtemplate-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_template_email_template_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-template:emailtemplate-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_template_email_template_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-template:emailtemplate-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_template_email_template_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-template:emailtemplate-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_template_email_template_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-template:emailtemplate-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_template_email_template_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-template:emailtemplate-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_template_email_template_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-template:emailtemplate-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
