# -*- coding: utf-8 -*-

from rest_framework import serializers
from thx.api.serializers import (
    ThuxCreateSerializerMixin, ThuxDisableSerializerMixin, ThuxEnableSerializerMixin, ThuxListSerializerMixin,
    ThuxPartialUpdateSerializerMixin, ThuxRetrieveSerializerMixin, ThuxUpdateSerializerMixin,
)

from ... import models


# GENERIC TEMPLATE
class GenericTemplateSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_generic_template'
        model = models.GenericTemplate
        fields = '__all__'


class GenericTemplateListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_generic_template_list'
        model = models.GenericTemplate
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class GenericTemplateRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_generic_template_retrieve'
        model = models.GenericTemplate
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class GenericTemplateCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_generic_template_create'
        model = models.GenericTemplate
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []

    def to_representation(self, instance):
        return GenericTemplateListSerializer(instance, context=self.context).data


class GenericTemplateUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_generic_template_update'
        model = models.GenericTemplate
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []

    def to_representation(self, instance):
        return GenericTemplateRetrieveSerializer(instance, context=self.context).data


class GenericTemplatePartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_generic_template_partial_update'
        model = models.GenericTemplate
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []

    def to_representation(self, instance):
        return GenericTemplateRetrieveSerializer(instance, context=self.context).data


class GenericTemplateEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_generic_template_enable'
        model = models.GenericTemplate
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    def to_representation(self, instance):
        return GenericTemplateRetrieveSerializer(instance, context=self.context).data


class GenericTemplateDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_generic_template_disable'
        model = models.GenericTemplate
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    def to_representation(self, instance):
        return GenericTemplateRetrieveSerializer(instance, context=self.context).data


class GenericTemplateLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_generic_template_light'
        model = models.GenericTemplate
        fields = ('id', 'status', 'status_display',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


# EMAIL TEMPLATE
class EmailTemplateSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_email_template'
        model = models.EmailTemplate
        fields = '__all__'


class EmailTemplateListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_email_template_list'
        model = models.EmailTemplate
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class EmailTemplateRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_email_template_retrieve'
        model = models.EmailTemplate
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class EmailTemplateCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_email_template_create'
        model = models.EmailTemplate
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []

    def to_representation(self, instance):
        return EmailTemplateListSerializer(instance, context=self.context).data


class EmailTemplateUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_email_template_update'
        model = models.EmailTemplate
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []

    def to_representation(self, instance):
        return EmailTemplateRetrieveSerializer(instance, context=self.context).data


class EmailTemplatePartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_email_template_partial_update'
        model = models.EmailTemplate
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []

    def to_representation(self, instance):
        return EmailTemplateRetrieveSerializer(instance, context=self.context).data


class EmailTemplateEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_email_template_enable'
        model = models.EmailTemplate
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    def to_representation(self, instance):
        return EmailTemplateRetrieveSerializer(instance, context=self.context).data


class EmailTemplateDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_email_template_disable'
        model = models.EmailTemplate
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    def to_representation(self, instance):
        return EmailTemplateRetrieveSerializer(instance, context=self.context).data


class EmailTemplateLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_email_template_light'
        model = models.EmailTemplate
        fields = ('id', 'status', 'status_display',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []
